==> alloy-ui-3.0.2.jar: META-INF/resources/webjars/alloy-ui/3.0.2/src/aui-datepicker/HISTORY.md <==
# AUI DatePicker

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-datepicker).

## @VERSION@

No registries yet.

## [3.0.1](https://github.com/liferay/alloy-ui/releases/tag/3.0.1)

* [AUI-1169](https://issues.liferay.com/browse/AUI-1169) DatePicker does not disappear on blur of trigger
* [AUI-1783](https://issues.liferay.com/browse/AUI-1783) Add enter key input event listener to the Datepicker module
* [AUI-1795](https://issues.liferay.com/browse/AUI-1795) DatePicker throws "Uncaught TypeError" when getPopover() is called and anything other than trigger is clicked
* [AUI-1205](https://issues.liferay.com/browse/AUI-1205) datePicker fires selectionChange event when trigger is clicked

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1613](DatePicker does not set value of trigger when date selected while picker is partially out of view)
* [AUI-1270](https://issues.liferay.com/browse/AUI-1270) Remove date normalization code once YUI releases the appropriate fix
* [AUI-1287](https://issues.liferay.com/browse/AUI-1287) Wrong css formatting when running "grunt format"

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1177](https://issues.liferay.com/browse/AUI-1177) Date disappears from input textbox when choosing the minimumDate from the DatePicker
* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants

==> alloy-ui-3.0.3.jar: META-INF/resources/webjars/alloy-ui/3.0.3/src/aui-datepicker/HISTORY.md <==
# AUI DatePicker

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-datepicker).

## @VERSION@

No registries yet.

## [3.0.3](https://github.com/liferay/alloy-ui/releases/tag/3.0.3)

No changes.

## [3.0.2](https://github.com/liferay/alloy-ui/releases/tag/3.0.2)

No changes.

## [3.0.1](https://github.com/liferay/alloy-ui/releases/tag/3.0.1)

* [AUI-1169](https://issues.liferay.com/browse/AUI-1169) DatePicker does not disappear on blur of trigger
* [AUI-1783](https://issues.liferay.com/browse/AUI-1783) Add enter key input event listener to the Datepicker module
* [AUI-1795](https://issues.liferay.com/browse/AUI-1795) DatePicker throws "Uncaught TypeError" when getPopover() is called and anything other than trigger is clicked
* [AUI-1205](https://issues.liferay.com/browse/AUI-1205) datePicker fires selectionChange event when trigger is clicked

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1613](DatePicker does not set value of trigger when date selected while picker is partially out of view)
* [AUI-1270](https://issues.liferay.com/browse/AUI-1270) Remove date normalization code once YUI releases the appropriate fix
* [AUI-1287](https://issues.liferay.com/browse/AUI-1287) Wrong css formatting when running "grunt format"

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1177](https://issues.liferay.com/browse/AUI-1177) Date disappears from input textbox when choosing the minimumDate from the DatePicker
* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants
